Struct SocketBuffer
Source struct SocketBuffer {
data: RwLock<VecDeque<u8>>,
closed: RwLock<bool>,
}
Shared buffer structure for socket data
Flag indicating this buffer has been closed (peer shutdown)
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.